@@ -31,13 +31,21 @@ pub enum ParseErr {
     /// No value was provided for the jobs flag.
     JobsNoValue,
     /// An invalid argument flag was provided.
-    InvalidArgument(String),
+    InvalidArgument(usize),
+    /// The value for `max_args` was not set to a number.
+    MaxArgsNaN(usize),
+    /// No value was provided for the `max_args` flag.
+    MaxArgsNoValue,
     /// No arguments were given, so no action can be taken.
     NoArguments,
 }
 
+impl From<FileErr> for ParseErr {
+    fn from(input: FileErr) -> ParseErr { ParseErr::File(input) }
+}
+
 impl ParseErr {
-    pub fn handle(self) -> ! {
+    pub fn handle(self, arguments: &[String]) -> ! {
         // Always lock an output buffer before using it.
         let stderr = stderr();
         let stdout = stdout();
@@ -77,8 +85,14 @@ impl ParseErr {
             ParseErr::JobsNoValue => {
                 let _ = stderr.write(b"no jobs parameter was defined.\n");
             },
-            ParseErr::InvalidArgument(argument) => {
-                let _ = write!(stderr, "invalid argument: {}\n", argument);
+            ParseErr::MaxArgsNaN(index) => {
+                let _ = write!(stderr, "groups parameter, '{}', is not a number.\n", arguments[index]);
+            },
+            ParseErr::MaxArgsNoValue => {
+                let _ = stderr.write(b"no groups parameter was defined.\n");
+            }
+            ParseErr::InvalidArgument(index) => {
+                let _ = write!(stderr, "invalid argument: {}\n", arguments[index]);
             },
             ParseErr::NoArguments => {
                 let _ = write!(stderr, "no input arguments were given.\n");
